@@ -1,5 +1,8 @@
 #!/bin/bash
 
+# https://github.com/conda-forge/gsl-feedstock/issues/34#issuecomment-449305702
+export LIBS="-lcblas -lm"
+
 ./configure --prefix=${PREFIX}  \
             --host=${HOST}
 
